@@ -7,7 +7,7 @@ information.
 __author__ = "Michael Stephens <mstephens@sunlightfoundation.com>"
 __copyright__ = "Copyright (c) 2011 Sunlight Labs"
 __license__ = "BSD"
-__version__ = "0.5.0"
+__version__ = "0.5.1"
 
 from remoteobjects import RemoteObject, fields, ListObject
 import urllib
@@ -16,6 +16,10 @@ OPENSTATES_URL = "http://openstates.sunlightlabs.com/api/v1/"
 
 API_KEY = ''
 
+raise DeprecationWarning('python-openstates is deprecated in favor of '
+                         'python-sunlight\n'
+                         'http://python-sunlight.readthedocs.org/')
+
 
 class OpenStateDatetime(fields.Datetime):
     """
